@@ -48,7 +48,6 @@ class StandardCalendarActionManager::Private
       mGenericManager = new StandardActionManager( actionCollection, parentWidget );
       mParent->connect( mGenericManager, SIGNAL(actionStateUpdated()),
                         mParent, SIGNAL(actionStateUpdated()) );
-
       mGenericManager->setMimeTypeFilter( QStringList() << QLatin1String( "text/calendar" ) );
       mGenericManager->setCapabilityFilter( QStringList() << QLatin1String( "Resource" ) );
     }
@@ -685,4 +684,4 @@ void StandardCalendarActionManager::setCollectionPropertiesPageNames( const QStr
   d->mGenericManager->setCollectionPropertiesPageNames( names );
 }
 
-#include "standardcalendaractionmanager.moc"
+#include "moc_standardcalendaractionmanager.cpp"
