@@ -50,16 +50,16 @@
 
 #include <QtCore/QDirIterator>
 #include <QtCore/QPluginLoader>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLayout>
-#include <QtGui/QCheckBox>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
+#include <QCheckBox>
 
 class ContactEditorWidget::Private
 {
   public:
-    Private( ContactEditorWidget *parent )
-      : mParent( parent )
+    Private( ContactEditorWidget::DisplayMode displayMode, ContactEditorWidget *parent )
+      : mDisplayMode(displayMode), mParent( parent ), mCustomFieldsWidget(0)
     {
     }
 
@@ -76,6 +76,7 @@ class ContactEditorWidget::Private
     QString loadCustom( const KABC::Addressee &contact, const QString &key ) const;
     void storeCustom( KABC::Addressee &contact, const QString &key, const QString &value ) const;
 
+    ContactEditorWidget::DisplayMode mDisplayMode;
     ContactEditorWidget *mParent;
     KTabWidget *mTabWidget;
 
@@ -150,9 +151,10 @@ void ContactEditorWidget::Private::initGui()
   initGuiBusinessTab();
   initGuiPersonalTab();
   initGuiNotesTab();
-  initGuiCustomFieldsTab();
-
-  loadCustomPages();
+  if(mDisplayMode == FullMode) {
+    initGuiCustomFieldsTab();
+    loadCustomPages();
+  }
 }
 
 void ContactEditorWidget::Private::initGuiContactTab()
@@ -254,17 +256,17 @@ void ContactEditorWidget::Private::initGuiContactTab()
   mPhonesWidget = new PhoneEditWidget;
   phonesLayout->addWidget( mPhonesWidget, 0, 0 );
 
-  phonesLayout->setRowStretch( 1, 1 );
+  //phonesLayout->setRowStretch( 1, 1 );
 
   // setup categories section
-  const bool nepomukInitialized(Nepomuk::ResourceManager::instance()->initialized());
+  const bool nepomukInitialized( Nepomuk::ResourceManager::instance()->initialized() );
   QHBoxLayout *categoriesLayout = new QHBoxLayout;
   label = new QLabel( i18nc( "@label The categories of a contact", "Categories:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
-  label->setVisible(nepomukInitialized);
+  label->setVisible( nepomukInitialized );
 
   mCategoriesWidget = new CategoriesEditWidget;
-  mCategoriesWidget->setVisible(nepomukInitialized);
+  mCategoriesWidget->setVisible( nepomukInitialized );
   label->setBuddy( mCategoriesWidget );
 
   categoriesLayout->addWidget( label );
@@ -277,7 +279,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   mMailPreferFormatting = new KComboBox;
   QStringList listFormat;
-  listFormat<<i18n( "Unknown" ) <<i18n( "Plain Text" ) << i18n( "HTML" );
+  listFormat << i18n( "Unknown" ) << i18n( "Plain Text" ) << i18n( "HTML" );
   mMailPreferFormatting->addItems( listFormat );
   mailPreferFormattingLayout->addWidget( label );
   mailPreferFormattingLayout->addWidget( mMailPreferFormatting );
@@ -488,18 +490,21 @@ void ContactEditorWidget::Private::loadCustomPages()
   QDirIterator it( pluginDirectory, QDir::Files );
   while ( it.hasNext() ) {
     QPluginLoader loader( it.next() );
-    if ( !loader.load() )
+    if ( !loader.load() ) {
       continue;
+    }
 
     Akonadi::ContactEditorPagePlugin *plugin = qobject_cast<Akonadi::ContactEditorPagePlugin*>( loader.instance() );
-    if ( !plugin )
+    if ( !plugin ) {
       continue;
+    }
 
     mCustomPages.append( plugin );
   }
 
-  foreach ( Akonadi::ContactEditorPagePlugin *plugin, mCustomPages )
+  foreach ( Akonadi::ContactEditorPagePlugin *plugin, mCustomPages ) {
     mTabWidget->addTab( plugin, plugin->title() );
+  }
 }
 
 QString ContactEditorWidget::Private::loadCustom( const KABC::Addressee &contact, const QString &key ) const
@@ -509,14 +514,26 @@ QString ContactEditorWidget::Private::loadCustom( const KABC::Addressee &contact
 
 void ContactEditorWidget::Private::storeCustom( KABC::Addressee &contact, const QString &key, const QString &value ) const
 {
-  if ( value.isEmpty() )
+  if ( value.isEmpty() ) {
     contact.removeCustom( QLatin1String( "KADDRESSBOOK" ), key );
-  else
+  } else {
     contact.insertCustom( QLatin1String( "KADDRESSBOOK" ), key, value );
+  }
 }
 
 ContactEditorWidget::ContactEditorWidget( QWidget* )
-  : d( new Private( this ) )
+  : d( new Private( FullMode, this ) )
+{
+  d->initGui();
+
+  connect( d->mNameWidget, SIGNAL(nameChanged(KABC::Addressee)),
+           d->mDisplayNameWidget, SLOT(changeName(KABC::Addressee)) );
+  connect( d->mOrganizationWidget, SIGNAL(textChanged(QString)),
+           d->mDisplayNameWidget, SLOT(changeOrganization(QString)) );
+}
+
+ContactEditorWidget::ContactEditorWidget( ContactEditorWidget::DisplayMode displayMode, QWidget * )
+  : d( new Private( displayMode, this ) )
 {
   d->initGui();
 
@@ -554,14 +571,15 @@ void ContactEditorWidget::loadContact( const KABC::Addressee &contact, const Ako
 
 
   const QString mailPreferedFormatting = d->loadCustom( contact, QLatin1String( "MailPreferedFormatting" ) );
-  if ( mailPreferedFormatting.isEmpty() )
+  if ( mailPreferedFormatting.isEmpty() ) {
     d->mMailPreferFormatting->setCurrentIndex( 0 );
-  else if ( mailPreferedFormatting == QLatin1String( "TEXT" ) )
+  } else if ( mailPreferedFormatting == QLatin1String( "TEXT" ) ) {
     d->mMailPreferFormatting->setCurrentIndex( 1 );
-  else if ( mailPreferedFormatting == QLatin1String( "HTML" ) )
+  } else if ( mailPreferedFormatting == QLatin1String( "HTML" ) ) {
     d->mMailPreferFormatting->setCurrentIndex( 2 );
-  else
+  } else {
     d->mMailPreferFormatting->setCurrentIndex( 0 );
+  }
 
   const QString mailAllowToRemoteContent = d->loadCustom( contact, QLatin1String( "MailAllowToRemoteContent" ) );
   d->mAllowRemoteContent->setChecked( mailAllowToRemoteContent == QLatin1String( "TRUE" ) );
@@ -598,13 +616,16 @@ void ContactEditorWidget::loadContact( const KABC::Addressee &contact, const Ako
 
   d->mDisplayNameWidget->setDisplayType( (DisplayNameEditWidget::DisplayType)metaData.displayNameMode() );
 
-  // custom fields group
-  d->mCustomFieldsWidget->setLocalCustomFieldDescriptions( metaData.customFieldDescriptions() );
-  d->mCustomFieldsWidget->loadContact( contact );
+  if(d->mDisplayMode == FullMode) {
+    // custom fields group
+    d->mCustomFieldsWidget->setLocalCustomFieldDescriptions( metaData.customFieldDescriptions() );
+    d->mCustomFieldsWidget->loadContact( contact );
 
-  // custom pages
-  foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages )
-    plugin->loadContact( contact );
+    // custom pages
+    foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages ) {
+      plugin->loadContact( contact );
+    }
+  }
 }
 
 void ContactEditorWidget::storeContact( KABC::Addressee &contact, Akonadi::ContactMetaData &metaData ) const
@@ -642,8 +663,9 @@ void ContactEditorWidget::storeContact( KABC::Addressee &contact, Akonadi::Conta
   d->storeCustom( contact, QLatin1String( "MailPreferedFormatting" ), mailPreferedFormatting );
 
   QString mailAllowToRemoteContent;
-  if ( d->mAllowRemoteContent->isChecked() )
+  if ( d->mAllowRemoteContent->isChecked() ) {
     mailAllowToRemoteContent = QLatin1String( "TRUE" );
+  }
   d->storeCustom( contact, QLatin1String( "MailAllowToRemoteContent" ), mailAllowToRemoteContent );
 
   // address group
@@ -680,15 +702,18 @@ void ContactEditorWidget::storeContact( KABC::Addressee &contact, Akonadi::Conta
   // family group
   d->storeCustom( contact, QLatin1String( "X-SpousesName" ), d->mPartnerWidget->text().trimmed() );
 
-  // custom fields group
-  d->mCustomFieldsWidget->storeContact( contact );
-  metaData.setCustomFieldDescriptions( d->mCustomFieldsWidget->localCustomFieldDescriptions() );
+  if(d->mDisplayMode == FullMode) {
+    // custom fields group
+    d->mCustomFieldsWidget->storeContact( contact );
+    metaData.setCustomFieldDescriptions( d->mCustomFieldsWidget->localCustomFieldDescriptions() );
 
-  metaData.setDisplayNameMode( d->mDisplayNameWidget->displayType() );
+    metaData.setDisplayNameMode( d->mDisplayNameWidget->displayType() );
 
-  // custom pages
-  foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages )
-    plugin->storeContact( contact );
+    // custom pages
+    foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages ) {
+      plugin->storeContact( contact );
+    }
+  }
 }
 
 void ContactEditorWidget::setReadOnly( bool readOnly )
@@ -745,10 +770,13 @@ void ContactEditorWidget::setReadOnly( bool readOnly )
   // widgets from family group
   d->mPartnerWidget->setReadOnly( readOnly );
 
-  // widgets from custom fields group
-  d->mCustomFieldsWidget->setReadOnly( readOnly );
+  if(d->mDisplayMode == FullMode) {
+    // widgets from custom fields group
+    d->mCustomFieldsWidget->setReadOnly( readOnly );
 
-  // custom pages
-  foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages )
-    plugin->setReadOnly( readOnly );
+    // custom pages
+    foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages ) {
+      plugin->setReadOnly( readOnly );
+    }
+  }
 }
