@@ -21,14 +21,14 @@
 
 #include "freebusyeditwidget.h"
 
-#include <QtGui/QHBoxLayout>
+#include <QHBoxLayout>
 
 #include <kabc/addressee.h>
 #include <kcalcore/freebusyurlstore.h>
 #include <kurlrequester.h>
 
 FreeBusyEditWidget::FreeBusyEditWidget( QWidget *parent )
-  : QWidget( parent ), mReadOnly( false )
+  : QWidget( parent )
 {
   QHBoxLayout *layout = new QHBoxLayout( this );
   layout->setMargin( 0 );
@@ -43,16 +43,18 @@ FreeBusyEditWidget::~FreeBusyEditWidget()
 
 void FreeBusyEditWidget::loadContact( const KABC::Addressee &contact )
 {
-  if ( contact.preferredEmail().isEmpty() )
+  if ( contact.preferredEmail().isEmpty() ) {
     return;
+  }
 
-  mURL->setUrl( KCalCore::FreeBusyUrlStore::self()->readUrl( contact.preferredEmail() ) );
+  mURL->setUrl( QUrl(KCalCore::FreeBusyUrlStore::self()->readUrl( contact.preferredEmail() ) ) );
 }
 
 void FreeBusyEditWidget::storeContact( KABC::Addressee &contact ) const
 {
-  if ( contact.preferredEmail().isEmpty() )
+  if ( contact.preferredEmail().isEmpty() ) {
     return;
+  }
 
   KCalCore::FreeBusyUrlStore::self()->writeUrl( contact.preferredEmail(), mURL->url().url() );
   KCalCore::FreeBusyUrlStore::self()->sync();
@@ -63,4 +65,3 @@ void FreeBusyEditWidget::setReadOnly( bool readOnly )
   mURL->setEnabled( !readOnly );
 }
 
-#include "freebusyeditwidget.moc"
