@@ -55,9 +55,9 @@
 #include <KToggleAction>
 
 #include <QtCore/QMimeData>
-#include <QtGui/QApplication>
-#include <QtGui/QClipboard>
-#include <QtGui/QItemSelectionModel>
+#include <QApplication>
+#include <QClipboard>
+#include <QItemSelectionModel>
 #include <QWeakPointer>
 
 #include <boost/static_assert.hpp>
@@ -602,7 +602,9 @@ class StandardActionManager::Private
       }
       if ( name.startsWith( QLatin1Char('.') ) ||
            name.endsWith( QLatin1Char('.') ) ) {
-          kDebug()<<" We can not add \".\" at begin or end of folder name ";
+        KMessageBox::error( parentWidget,
+                            i18n( "We can not add \".\" at begin or end of folder name." ),
+                            i18n( "Create new folder error" ) );
         return;
       }
 
@@ -792,7 +794,7 @@ class StandardActionManager::Private
     {
       Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance( collection.resource() );
       if ( !instance.isOnline() ) {
-        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before syncing folder \"%1\" it's necessary to have resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
+        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before syncing folder \"%1\" it is necessary to have the resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
           return false;
         instance.setIsOnline( true );
       }
@@ -1275,7 +1277,7 @@ class StandardActionManager::Private
      */
     bool isWritableTargetCollectionForMimeTypes( const Collection &collection, const QSet<QString> &mimeTypes, StandardActionManager::Type type ) const
     {
-      if ( CollectionUtils::isVirtual( collection ) )
+      if ( collection.isVirtual() )
         return false;
 
       const bool isItemAction = ( type == CopyItemToMenu || type == MoveItemToMenu );
@@ -1303,7 +1305,7 @@ class StandardActionManager::Private
         const QModelIndex index = model->index( row, 0, parentIndex );
         const Collection collection = model->data( index, CollectionModel::CollectionRole ).value<Collection>();
 
-        if ( CollectionUtils::isVirtual( collection ) )
+        if ( collection.isVirtual() )
           continue;
 
         const bool readOnly = !isWritableTargetCollectionForMimeTypes( collection, mimeTypes, type );
@@ -1698,4 +1700,4 @@ void StandardActionManager::createActionFolderMenu(QMenu *menu, Type type)
 
 
 
-#include "standardactionmanager.moc"
+#include "moc_standardactionmanager.cpp"
