@@ -18,7 +18,6 @@
 */
 
 #include "searchjobtest.h"
-#include "searchjobtest.moc"
 
 #include <akonadi/collection.h>
 #include <akonadi/collectiondeletejob.h>
@@ -54,7 +53,7 @@ void SearchJobTest::testCreateDeleteSearch()
   }
   QVERIFY( col == created );
   QCOMPARE( col.parentCollection().id(), 1LL );
-  QVERIFY( CollectionUtils::isVirtual( col ) );
+  QVERIFY( col.isVirtual() );
 
   CollectionDeleteJob *delJob = new CollectionDeleteJob( col, this );
   AKVERIFYEXEC( delJob );
