@@ -55,7 +55,6 @@ using namespace KCalCore;
 
 static const char APP_NAME_FOR_XPROPERTIES[] = "KCALCORE";
 static const char ENABLED_ALARM_XPROPERTY[] = "ENABLED";
-static const char IMPLEMENTATION_VERSION_XPROPERTY[] = "X-KDE-ICAL-IMPLEMENTATION-VERSION";
 
 /* Static helpers */
 /*
@@ -208,10 +207,10 @@ icalcomponent *ICalFormatImpl::writeTodo( const Todo::Ptr &todo, ICalTimeZones *
     icaltimetype due;
     if ( todo->allDay() ) {
       due = writeICalDate( todo->dtDue( true ).date() );
-      prop = icalproperty_new_due(due);
+      prop = icalproperty_new_due( due );
     } else {
       prop = writeICalDateTimeProperty(
-        ICAL_DUE_PROPERTY, todo->dtDue(true), tzlist, tzUsedList );
+        ICAL_DUE_PROPERTY, todo->dtDue( true ), tzlist, tzUsedList );
     }
     icalcomponent_add_property( vtodo, prop );
   }
@@ -298,7 +297,7 @@ icalcomponent *ICalFormatImpl::writeEvent( const Event::Ptr &event,
 #else
       end = writeICalDate( dt.date() );
 #endif
-      icalcomponent_add_property( vevent, icalproperty_new_dtend(end) );
+      icalcomponent_add_property( vevent, icalproperty_new_dtend( end ) );
     } else {
       if ( dt != event->dtStart() ) {
         icalcomponent_add_property(
@@ -320,7 +319,7 @@ icalcomponent *ICalFormatImpl::writeEvent( const Event::Ptr &event,
 #endif
 
   // Transparency
-  switch( event->transparency() ) {
+  switch ( event->transparency() ) {
   case Event::Transparent:
     icalcomponent_add_property(
       vevent,
@@ -412,10 +411,10 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
 
   d->writeIncidenceBase( parent, incidence.staticCast<IncidenceBase>() );
 
-  // creation date in storage
+  // creation time of ical object
   icalcomponent_add_property(
     parent, writeICalDateTimeProperty(
-      ICAL_CREATED_PROPERTY, incidence->created() ) );
+      ICAL_DTSTAMP_PROPERTY, incidence->created() ) );
 
   // unique id
   // If the scheduling ID is different from the real UID, the real
@@ -557,21 +556,21 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
   RecurrenceRule::List::ConstIterator rit;
   for ( rit = rrules.constBegin(); rit != rrules.constEnd(); ++rit ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_rrule( writeRecurrenceRule( (*rit) ) ) );
+      parent, icalproperty_new_rrule( writeRecurrenceRule( ( *rit ) ) ) );
   }
 
   RecurrenceRule::List exrules( incidence->recurrence()->exRules() );
   RecurrenceRule::List::ConstIterator exit;
   for ( exit = exrules.constBegin(); exit != exrules.constEnd(); ++exit ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_exrule( writeRecurrenceRule( (*exit) ) ) );
+      parent, icalproperty_new_exrule( writeRecurrenceRule( ( *exit ) ) ) );
   }
 
   DateList dateList = incidence->recurrence()->exDates();
   DateList::ConstIterator exIt;
   for ( exIt = dateList.constBegin(); exIt != dateList.constEnd(); ++exIt ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_exdate( writeICalDate(*exIt) ) );
+      parent, icalproperty_new_exdate( writeICalDate( *exIt ) ) );
   }
 
   DateTimeList dateTimeList = incidence->recurrence()->exDateTimes();
@@ -585,7 +584,7 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
   DateList::ConstIterator rdIt;
   for ( rdIt = dateList.constBegin(); rdIt != dateList.constEnd(); ++rdIt ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_rdate( writeICalDatePeriod(*rdIt) ) );
+      parent, icalproperty_new_rdate( writeICalDatePeriod( *rdIt ) ) );
   }
   dateTimeList = incidence->recurrence()->rDateTimes();
   DateTimeList::ConstIterator rdtIt;
@@ -620,6 +619,11 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
 void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
                                                   IncidenceBase::Ptr incidenceBase )
 {
+  // creation date in storage
+  icalcomponent_add_property(
+    parent, writeICalDateTimeProperty(
+      ICAL_CREATED_PROPERTY, KDateTime::currentUtcDateTime() ) );
+
   // organizer stuff
   if ( !incidenceBase->organizer()->isEmpty() ) {
     icalproperty *p = mImpl->writeOrganizer( incidenceBase->organizer() );
@@ -628,9 +632,6 @@ void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
     }
   }
 
-  icalcomponent_add_property(
-    parent, icalproperty_new_dtstamp( writeICalUtcDateTime( incidenceBase->lastModified() ) ) );
-
   // attendees
   if ( incidenceBase->attendeeCount() > 0 ) {
     Attendee::List::ConstIterator it;
@@ -646,13 +647,13 @@ void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
   //contacts
   QStringList contacts = incidenceBase->contacts();
   for ( QStringList::const_iterator it = contacts.constBegin(); it != contacts.constEnd(); ++it ) {
-    icalcomponent_add_property( parent, icalproperty_new_contact( (*it).toUtf8() ) );
+    icalcomponent_add_property( parent, icalproperty_new_contact( ( *it ).toUtf8() ) );
   }
 
   // comments
   QStringList comments = incidenceBase->comments();
   for ( QStringList::const_iterator it = comments.constBegin(); it != comments.constEnd(); ++it ) {
-    icalcomponent_add_property( parent, icalproperty_new_comment( (*it).toUtf8() ) );
+    icalcomponent_add_property( parent, icalproperty_new_comment( ( *it ).toUtf8() ) );
   }
 
   // custom properties
@@ -866,7 +867,7 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
   icalrecurrencetype r;
   icalrecurrencetype_clear( &r );
 
-  switch( recur->recurrenceType() ) {
+  switch ( recur->recurrenceType() ) {
   case RecurrenceRule::rSecondly:
     r.freq = ICAL_SECONDLY_RECURRENCE;
     break;
@@ -956,12 +957,12 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
   index = 0;
   for ( QList<RecurrenceRule::WDayPos>::ConstIterator dit = byd.constBegin();
         dit != byd.constEnd(); ++dit ) {
-    day = (*dit).day() % 7 + 1;     // convert from Monday=1 to Sunday=1
-    if ( (*dit).pos() < 0 ) {
-      day += ( -(*dit).pos() ) * 8;
+    day = ( *dit ).day() % 7 + 1;     // convert from Monday=1 to Sunday=1
+    if ( ( *dit ).pos() < 0 ) {
+      day += ( -( *dit ).pos() ) * 8;
       day = -day;
     } else {
-      day += (*dit).pos() * 8;
+      day += ( *dit ).pos() * 8;
     }
     r.by_day[index++] = static_cast<short>( day );
   }
@@ -1027,11 +1028,11 @@ icalcomponent *ICalFormatImpl::writeAlarm( const Alarm::Ptr &alarm )
     const Person::List addresses = alarm->mailAddresses();
     for ( Person::List::ConstIterator ad = addresses.constBegin();
           ad != addresses.constEnd();  ++ad ) {
-      if ( !(*ad)->email().isEmpty() ) {
-        icalproperty *p = icalproperty_new_attendee( "MAILTO:" + (*ad)->email().toUtf8() );
-        if ( !(*ad)->name().isEmpty() ) {
+      if ( !( *ad )->email().isEmpty() ) {
+        icalproperty *p = icalproperty_new_attendee( "MAILTO:" + ( *ad )->email().toUtf8() );
+        if ( !( *ad )->name().isEmpty() ) {
           icalproperty_add_parameter(
-            p, icalparameter_new_cn( quoteForParam( (*ad)->name() ).toUtf8() ) );
+            p, icalparameter_new_cn( quoteForParam( ( *ad )->name() ).toUtf8() ) );
         }
         icalcomponent_add_property( a, p );
       }
@@ -1114,7 +1115,7 @@ Todo::Ptr ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist
   icalproperty *p = icalcomponent_get_first_property( vtodo, ICAL_ANY_PROPERTY );
 
   while ( p ) {
-    icalproperty_kind kind = icalproperty_isa(p);
+    icalproperty_kind kind = icalproperty_isa( p );
     switch ( kind ) {
     case ICAL_DUE_PROPERTY:
     { // due date/time
@@ -1360,7 +1361,7 @@ Attendee::Ptr ICalFormatImpl::readAttendee( icalproperty *attendee )
   p = icalproperty_get_first_parameter( attendee, ICAL_PARTSTAT_PARAMETER );
   if ( p ) {
     icalparameter_partstat partStatParameter = icalparameter_get_partstat( p );
-    switch( partStatParameter ) {
+    switch ( partStatParameter ) {
     default:
     case ICAL_PARTSTAT_NEEDSACTION:
       status = Attendee::NeedsAction;
@@ -1390,7 +1391,7 @@ Attendee::Ptr ICalFormatImpl::readAttendee( icalproperty *attendee )
   p = icalproperty_get_first_parameter( attendee, ICAL_ROLE_PARAMETER );
   if ( p ) {
     icalparameter_role roleParameter = icalparameter_get_role( p );
-    switch( roleParameter ) {
+    switch ( roleParameter ) {
     case ICAL_ROLE_CHAIR:
       role = Attendee::Chair;
       break;
@@ -1461,7 +1462,7 @@ Attachment::Ptr ICalFormatImpl::readAttachment( icalproperty *attach )
   QByteArray p;
   icalvalue *value = icalproperty_get_value( attach );
 
-  switch( icalvalue_isa( value ) ) {
+  switch ( icalvalue_isa( value ) ) {
   case ICAL_ATTACH_VALUE:
   {
     icalattach *a = icalproperty_get_attach( attach );
@@ -1542,19 +1543,14 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
   int intvalue, inttext;
   icaldurationtype icalduration;
   KDateTime kdt;
-  KDateTime dtstamp;
 
   QStringList categories;
 
   while ( p ) {
     icalproperty_kind kind = icalproperty_isa( p );
     switch ( kind ) {
-    case ICAL_CREATED_PROPERTY:
-      incidence->setCreated( readICalDateTimeProperty( p, tzlist ) );
-      break;
-
     case ICAL_DTSTAMP_PROPERTY:
-      dtstamp = readICalDateTimeProperty( p, tzlist );
+      incidence->setCreated( readICalDateTimeProperty( p, tzlist ) );
       break;
 
     case ICAL_SEQUENCE_PROPERTY:  // sequence
@@ -1789,11 +1785,9 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
        alarm = icalcomponent_get_next_component( parent, ICAL_VALARM_COMPONENT ) ) {
     readAlarm( alarm, incidence, tzlist );
   }
-
+  // Fix incorrect alarm settings by other applications (like outloook 9)
   if ( d->mCompat ) {
-    // Fix incorrect alarm settings by other applications (like outloook 9)
     d->mCompat->fixAlarms( incidence );
-    d->mCompat->setCreatedToDtStamp( incidence, dtstamp );
   }
 }
 
@@ -1874,7 +1868,7 @@ void ICalFormatImpl::Private::readCustomProperties( icalcomponent *parent,
       }
     }
     const char *name = icalproperty_get_x_name( p );
-    QByteArray nproperty(name);
+    QByteArray nproperty( name );
     if ( property != nproperty ) {
       // New property
       if ( !property.isEmpty() ) {
@@ -2391,10 +2385,6 @@ KDateTime ICalFormatImpl::readICalDateTimeProperty( icalproperty *p,
   icaldatetimeperiodtype tp;
   icalproperty_kind kind = icalproperty_isa( p );
   switch ( kind ) {
-  case ICAL_CREATED_PROPERTY:   // UTC date/time
-    tp.time = icalproperty_get_created( p );
-    utc = true;
-    break;
   case ICAL_DTSTAMP_PROPERTY:   // UTC date/time
     tp.time = icalproperty_get_dtstamp( p );
     utc = true;
@@ -2531,12 +2521,7 @@ icalcomponent *ICalFormatImpl::createCalendarComponent( const Calendar::Ptr &cal
   icalcomponent_add_property( calendar, p );
 
   // iCalendar version (2.0)
-  p = icalproperty_new_version( const_cast<char *>(_ICAL_VERSION) );
-  icalcomponent_add_property( calendar, p );
-
-  // Implementation Version
-  p = icalproperty_new_x( _ICAL_IMPLEMENTATION_VERSION );
-  icalproperty_set_x_name( p, IMPLEMENTATION_VERSION_XPROPERTY );
+  p = icalproperty_new_version( const_cast<char *>( _ICAL_VERSION ) );
   icalcomponent_add_property( calendar, p );
 
   // Add time zone
@@ -2559,7 +2544,7 @@ icalcomponent *ICalFormatImpl::createCalendarComponent( const Calendar::Ptr &cal
   }
   */
   // Custom properties
-  if( cal != 0 ) {
+  if ( cal != 0 ) {
     d->writeCustomProperties( calendar, cal.data() );
   }
 
@@ -2572,7 +2557,7 @@ icalcomponent *ICalFormatImpl::createCalendarComponent( const Calendar::Ptr &cal
 bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar,
                                bool deleted, const QString &notebook )
 {
-  Q_UNUSED(notebook);
+  Q_UNUSED( notebook );
 
   // kDebug()<<"Populate called";
 
@@ -2580,7 +2565,7 @@ bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar
   // lists. It turns vevents into Events and then inserts them.
 
   if ( !calendar ) {
-    kDebug() << "Populate called with empty calendar";
+    kWarning() << "Populate called with empty calendar";
     return false;
   }
 
@@ -2588,27 +2573,6 @@ bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar
 
   icalproperty *p;
 
-  p = icalcomponent_get_first_property( calendar, ICAL_X_PROPERTY );
-  QString implementationVersion;
-
-  while ( p ) {
-    const char *name = icalproperty_get_x_name( p );
-    QByteArray nproperty( name );
-    kDebug() << nproperty;
-    if ( nproperty == QByteArray( IMPLEMENTATION_VERSION_XPROPERTY ) ) {
-      QString nvalue = QString::fromUtf8( icalproperty_get_x( p ) );
-      if ( nvalue.isEmpty() ) {
-        icalvalue *value = icalproperty_get_value( p );
-        if ( icalvalue_isa( value ) == ICAL_TEXT_VALUE ) {
-          nvalue = QString::fromUtf8( icalvalue_get_text( value ) );
-        }
-      }
-      implementationVersion = nvalue;
-      icalcomponent_remove_property( calendar, p );
-    }
-    p = icalcomponent_get_next_property( calendar, ICAL_X_PROPERTY );
-  }
-
   p = icalcomponent_get_first_property( calendar, ICAL_PRODID_PROPERTY );
   if ( !p ) {
     kDebug() << "No PRODID property found";
@@ -2617,7 +2581,7 @@ bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar
     d->mLoadedProductId = QString::fromUtf8( icalproperty_get_prodid( p ) );
 
     delete d->mCompat;
-    d->mCompat = CompatFactory::createCompat( d->mLoadedProductId, implementationVersion );
+    d->mCompat = CompatFactory::createCompat( d->mLoadedProductId );
   }
 
   p = icalcomponent_get_first_property( calendar, ICAL_VERSION_PROPERTY );
@@ -2703,7 +2667,7 @@ bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar
       Event::Ptr old = cal->event( event->uid(), event->recurrenceId() );
       if ( old ) {
         if ( old->uid().isEmpty() ) {
-          qWarning() << "Skipping invalid VEVENT";
+          kWarning() << "Skipping invalid VEVENT";
           c = icalcomponent_get_next_component( calendar, ICAL_VEVENT_COMPONENT );
           continue;
         }
@@ -2849,7 +2813,7 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( const IncidenceBase::Ptr
     const ICalTimeZones::ZoneMap zmaps = zones.zones();
     for ( ICalTimeZones::ZoneMap::ConstIterator it=zmaps.constBegin();
           it != zmaps.constEnd(); ++it ) {
-      icaltimezone *icaltz = (*it).icalTimezone();
+      icaltimezone *icaltz = ( *it ).icalTimezone();
       if ( !icaltz ) {
         kError() << "bad time zone";
       } else {
@@ -2865,7 +2829,7 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( const IncidenceBase::Ptr
 
   icalproperty_method icalmethod = ICAL_METHOD_NONE;
 
-  switch (method) {
+  switch ( method ) {
   case iTIPPublish:
     icalmethod = ICAL_METHOD_PUBLISH;
     break;
@@ -2898,13 +2862,6 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( const IncidenceBase::Ptr
   icalcomponent_add_property( message, icalproperty_new_method( icalmethod ) );
 
   icalcomponent *inc = writeIncidence( incidence, method );
-
-  if ( method != KCalCore::iTIPNoMethod ) {
-    //Not very nice, but since dtstamp changes semantics if used in scheduling, we have to adapt
-    icalcomponent_set_dtstamp(
-      inc, writeICalUtcDateTime( KDateTime::currentUtcDateTime() ) );
-  }
-
   /*
    * RFC 2446 states in section 3.4.3 ( REPLY to a VTODO ), that
    * a REQUEST-STATUS property has to be present. For the other two, event and
