@@ -32,7 +32,7 @@ namespace KIMAP
   class FetchJobPrivate : public JobPrivate
   {
     public:
-      FetchJobPrivate( FetchJob *job, Session *session, const QString& name ) : JobPrivate( session, name ), q(job), uidBased(false) { }
+      FetchJobPrivate( FetchJob *job, Session *session, const QString& name ) : JobPrivate( session, name ), q( job ), uidBased( false ) { }
       ~FetchJobPrivate() { }
 
       void parseBodyStructure( const QByteArray &structure, int &pos, KMime::Content *content );
@@ -87,9 +87,9 @@ namespace KIMAP
 using namespace KIMAP;
 
 FetchJob::FetchJob( Session *session )
-  : Job( *new FetchJobPrivate(this, session, i18n("Fetch")) )
+  : Job( *new FetchJobPrivate( this, session, i18n( "Fetch" ) ) )
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
   d->scope.mode = FetchScope::Content;
   connect( &d->emitPendingsTimer, SIGNAL(timeout()),
            this, SLOT(emitPendings()) );
@@ -101,38 +101,38 @@ FetchJob::~FetchJob()
 
 void FetchJob::setSequenceSet( const ImapSet &set )
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
   Q_ASSERT( !set.toImapSequenceSet().trimmed().isEmpty() );
   d->set = set;
 }
 
 ImapSet FetchJob::sequenceSet() const
 {
-  Q_D(const FetchJob);
+  Q_D( const FetchJob );
   return d->set;
 }
 
 void FetchJob::setUidBased(bool uidBased)
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
   d->uidBased = uidBased;
 }
 
 bool FetchJob::isUidBased() const
 {
-  Q_D(const FetchJob);
+  Q_D( const FetchJob );
   return d->uidBased;
 }
 
 void FetchJob::setScope( const FetchScope &scope )
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
   d->scope = scope;
 }
 
 FetchJob::FetchScope FetchJob::scope() const
 {
-  Q_D(const FetchJob);
+  Q_D( const FetchJob );
   return d->scope;
 }
 
@@ -163,7 +163,7 @@ QMap<qint64, qint64> FetchJob::uids() const
 
 void FetchJob::doStart()
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
 
   QByteArray parameters = d->set.toImapSequenceSet()+' ';
   Q_ASSERT( !parameters.trimmed().isEmpty() );
@@ -171,51 +171,51 @@ void FetchJob::doStart()
   switch ( d->scope.mode ) {
   case FetchScope::Headers:
     if ( d->scope.parts.isEmpty() ) {
-      parameters+="(RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] FLAGS UID)";
+      parameters += "(RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] FLAGS UID)";
     } else {
-      parameters+='(';
+      parameters += '(';
       foreach ( const QByteArray &part, d->scope.parts ) {
-        parameters+="BODY.PEEK["+part+".MIME] ";
+        parameters += "BODY.PEEK[" + part + ".MIME] ";
       }
-      parameters+="UID)";
+      parameters += "UID)";
     }
     break;
   case FetchScope::Flags:
-    parameters+="(FLAGS UID)";
+    parameters += "(FLAGS UID)";
     break;
   case FetchScope::Structure:
-    parameters+="(BODYSTRUCTURE UID)";
+    parameters += "(BODYSTRUCTURE UID)";
     break;
   case FetchScope::Content:
     if ( d->scope.parts.isEmpty() ) {
-      parameters+="(BODY.PEEK[] UID)";
+      parameters += "(BODY.PEEK[] UID)";
     } else {
-      parameters+='(';
+      parameters += '(';
       foreach ( const QByteArray &part, d->scope.parts ) {
-        parameters+="BODY.PEEK["+part+"] ";
+        parameters += "BODY.PEEK[" + part + "] ";
       }
-      parameters+="UID)";
+      parameters += "UID)";
     }
     break;
   case FetchScope::Full:
-    parameters+="(RFC822.SIZE INTERNALDATE BODY.PEEK[] FLAGS UID)";
+    parameters += "(RFC822.SIZE INTERNALDATE BODY.PEEK[] FLAGS UID)";
     break;
   case FetchScope::HeaderAndContent:
     if ( d->scope.parts.isEmpty() ) {
-      parameters+="(BODY.PEEK[] FLAGS UID)";
+      parameters += "(BODY.PEEK[] FLAGS UID)";
     } else {
-      parameters+="(BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)]";
+      parameters += "(BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)]";
       foreach ( const QByteArray &part, d->scope.parts ) {
-        parameters+=" BODY.PEEK["+part+".MIME] BODY.PEEK["+part+"]"; //krazy:exclude=doublequote_chars
+        parameters += " BODY.PEEK[" + part + ".MIME] BODY.PEEK[" + part + "]"; //krazy:exclude=doublequote_chars
       }
-      parameters+=" FLAGS UID)";
+      parameters += " FLAGS UID)";
     }
     break;
   }
 
   QByteArray command = "FETCH";
   if ( d->uidBased ) {
-    command = "UID "+command;
+    command = "UID " + command;
   }
 
   d->emitPendingsTimer.start( 100 );
@@ -225,21 +225,21 @@ void FetchJob::doStart()
 
 void FetchJob::handleResponse( const Message &response )
 {
-  Q_D(FetchJob);
+  Q_D( FetchJob );
 
   // We can predict it'll be handled by handleErrorReplies() so stop
   // the timer now so that result() will really be the last emitted signal.
-  if ( !response.content.isEmpty()
-       && d->tags.size() == 1
-       && d->tags.contains( response.content.first().toString() ) ) {
+  if ( !response.content.isEmpty() &&
+       d->tags.size() == 1 &&
+       d->tags.contains( response.content.first().toString() ) ) {
     d->emitPendingsTimer.stop();
     d->emitPendings();
   }
 
-  if (handleErrorReplies(response) == NotHandled ) {
-    if ( response.content.size() == 4
-           && response.content[2].toString()=="FETCH"
-           && response.content[3].type()==Message::Part::List ) {
+  if ( handleErrorReplies( response ) == NotHandled ) {
+    if ( response.content.size() == 4 &&
+         response.content[2].toString() == "FETCH" &&
+         response.content[3].type() == Message::Part::List ) {
 
       qint64 id = response.content[1].toString().toLongLong();
       QList<QByteArray> content = response.content[3].toList();
@@ -249,67 +249,69 @@ void FetchJob::handleResponse( const Message &response )
       MessageParts parts;
 
       for ( QList<QByteArray>::ConstIterator it = content.constBegin();
-            it!=content.constEnd(); ++it ) {
+            it != content.constEnd(); ++it ) {
         QByteArray str = *it;
         ++it;
 
-        if ( it==content.constEnd() ) { // Uh oh, message was truncated?
+        if ( it == content.constEnd() ) { // Uh oh, message was truncated?
           kWarning() << "FETCH reply got truncated, skipping.";
           break;
         }
 
-        if ( str=="UID" ) {
+        if ( str == "UID" ) {
           d->pendingUids[id] = it->toLongLong();
-        } else if ( str=="RFC822.SIZE" ) {
+        } else if ( str == "RFC822.SIZE" ) {
           d->pendingSizes[id] = it->toLongLong();
-        } else if ( str=="INTERNALDATE" ) {
+        } else if ( str == "INTERNALDATE" ) {
           message->date()->setDateTime( KDateTime::fromString( *it, KDateTime::RFCDate ) );
-        } else if ( str=="FLAGS" ) {
-          if ( (*it).startsWith('(') && (*it).endsWith(')') ) {
+        } else if ( str == "FLAGS" ) {
+          if ( ( *it ).startsWith( '(' ) && ( *it ).endsWith( ')' ) ) {
             QByteArray str = *it;
-            str.chop(1);
-            str.remove(0, 1);
-            d->pendingFlags[id] = str.split(' ');
+            str.chop( 1 );
+            str.remove( 0, 1 );
+            d->pendingFlags[id] = str.split( ' ' );
           } else {
             d->pendingFlags[id] << *it;
           }
-        } else if ( str=="BODYSTRUCTURE" ) {
+        } else if ( str == "BODYSTRUCTURE" ) {
           int pos = 0;
-          d->parseBodyStructure(*it, pos, message.get());
+          d->parseBodyStructure( *it, pos, message.get() );
           message->assemble();
           d->pendingMessages[id] = message;
-        } else if ( str.startsWith( "BODY[") ) { //krazy:exclude=strings
-          if ( !str.endsWith(']') ) { // BODY[ ... ] might have been split, skip until we find the ]
-            while ( !(*it).endsWith(']') ) ++it;
+        } else if ( str.startsWith( "BODY[" ) ) { //krazy:exclude=strings
+          if ( !str.endsWith( ']' ) ) { // BODY[ ... ] might have been split, skip until we find the ]
+            while ( !( *it ).endsWith( ']' ) ) {
+              ++it;
+            }
             ++it;
           }
 
           int index;
-          if ( (index=str.indexOf("HEADER"))>0 || (index=str.indexOf("MIME"))>0 ) { // headers
-            if ( str[index-1]=='.' ) {
-              QByteArray partId = str.mid( 5, index-6 );
+          if ( ( index = str.indexOf( "HEADER" ) ) > 0 || ( index = str.indexOf( "MIME" ) ) > 0 ) { // headers
+            if ( str[index-1] == '.' ) {
+              QByteArray partId = str.mid( 5, index - 6 );
               if ( !parts.contains( partId ) ) {
                   parts[partId] = ContentPtr( new KMime::Content );
               }
-              parts[partId]->setHead(*it);
+              parts[partId]->setHead( *it );
               parts[partId]->parse();
               d->pendingParts[id] = parts;
             } else {
-              message->setHead(*it);
+              message->setHead( *it );
               shouldParseMessage = true;
             }
           } else { // full payload
-            if ( str=="BODY[]" ) {
-              message->setContent( KMime::CRLFtoLF(*it) );
+            if ( str == "BODY[]" ) {
+              message->setContent( KMime::CRLFtoLF( *it ) );
               shouldParseMessage = true;
 
               d->pendingMessages[id] = message;
             } else {
-              QByteArray partId = str.mid( 5, str.size()-6 );
+              QByteArray partId = str.mid( 5, str.size() - 6 );
               if ( !parts.contains( partId ) ) {
                 parts[partId] = ContentPtr( new KMime::Content );
               }
-              parts[partId]->setBody(*it);
+              parts[partId]->setBody( *it );
               parts[partId]->parse();
 
               d->pendingParts[id] = parts;
@@ -334,21 +336,21 @@ void FetchJob::handleResponse( const Message &response )
 
 void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos, KMime::Content *content)
 {
-  skipLeadingSpaces(structure, pos);
+  skipLeadingSpaces( structure, pos );
 
-  if ( structure[pos]!='(' ) {
+  if ( structure[pos] != '(' ) {
     return;
   }
 
   pos++;
 
 
-  if ( structure[pos]!='(' ) { // simple part
+  if ( structure[pos] != '(' ) { // simple part
     pos--;
     parsePart( structure, pos, content );
   } else { // multi part
-    content->contentType()->setMimeType("MULTIPART/MIXED");
-    while ( pos<structure.size() && structure[pos]=='(' ) {
+    content->contentType()->setMimeType( "MULTIPART/MIXED" );
+    while ( pos < structure.size() && structure[pos] == '(' ) {
       KMime::Content *child = new KMime::Content;
       content->addContent( child );
       parseBodyStructure( structure, pos, child );
@@ -356,17 +358,17 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
     }
 
     QByteArray subType = parseString( structure, pos );
-    content->contentType()->setMimeType( "MULTIPART/"+subType );
+    content->contentType()->setMimeType( "MULTIPART/" + subType );
 
     QByteArray parameters = parseSentence( structure, pos ); // FIXME: Read the charset
-    if (parameters.contains("BOUNDARY") ) {
-      content->contentType()->setBoundary(parameters.remove(0, parameters.indexOf("BOUNDARY") + 11).split('\"')[0]);
+    if ( parameters.contains( "BOUNDARY" ) ) {
+      content->contentType()->setBoundary( parameters.remove( 0, parameters.indexOf( "BOUNDARY" ) + 11 ).split( '\"' )[0] );
     }
 
     QByteArray disposition = parseSentence( structure, pos );
-    if ( disposition.contains("INLINE") ) {
+    if ( disposition.contains( "INLINE" ) ) {
       content->contentDisposition()->setDisposition( KMime::Headers::CDinline );
-    } else if ( disposition.contains("ATTACHMENT") ) {
+    } else if ( disposition.contains( "ATTACHMENT" ) ) {
       content->contentDisposition()->setDisposition( KMime::Headers::CDattachment );
     }
 
@@ -374,7 +376,7 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
   }
 
   // Consume what's left
-  while ( pos<structure.size() && structure[pos]!=')' ) {
+  while ( pos < structure.size() && structure[pos] != ')' ) {
     skipLeadingSpaces( structure, pos );
     parseSentence( structure, pos );
     skipLeadingSpaces( structure, pos );
@@ -385,7 +387,7 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
 
 void FetchJobPrivate::parsePart( const QByteArray &structure, int &pos, KMime::Content *content )
 {
-  if ( structure[pos]!='(' ) {
+  if ( structure[pos] != '(' ) {
     return;
   }
 
@@ -394,7 +396,7 @@ void FetchJobPrivate::parsePart( const QByteArray &structure, int &pos, KMime::C
   QByteArray mainType = parseString( structure, pos );
   QByteArray subType = parseString( structure, pos );
 
-  content->contentType()->setMimeType( mainType+'/'+subType );
+  content->contentType()->setMimeType( mainType + '/' + subType );
 
   parseSentence( structure, pos ); // Ditch the parameters... FIXME: Read it to get charset and name
   parseString( structure, pos ); // ... and the id
@@ -406,20 +408,20 @@ void FetchJobPrivate::parsePart( const QByteArray &structure, int &pos, KMime::C
   parseString( structure, pos ); // ... and the line count
 
   QByteArray disposition = parseSentence( structure, pos );
-  if ( disposition.contains("INLINE") ) {
+  if ( disposition.contains( "INLINE" ) ) {
     content->contentDisposition()->setDisposition( KMime::Headers::CDinline );
-  } else if ( disposition.contains("ATTACHMENT") ) {
+  } else if ( disposition.contains( "ATTACHMENT" ) ) {
     content->contentDisposition()->setDisposition( KMime::Headers::CDattachment );
   }
-  if ( (content->contentDisposition()->disposition() == KMime::Headers::CDattachment
-        || content->contentDisposition()->disposition() == KMime::Headers::CDinline)
-       && disposition.contains("FILENAME") ) {
-    QByteArray filename = disposition.remove(0, disposition.indexOf("FILENAME") + 11).split('\"')[0];
+  if ( ( content->contentDisposition()->disposition() == KMime::Headers::CDattachment ||
+         content->contentDisposition()->disposition() == KMime::Headers::CDinline ) &&
+       disposition.contains( "FILENAME" ) ) {
+    QByteArray filename = disposition.remove( 0, disposition.indexOf( "FILENAME" ) + 11 ).split( '\"' )[0];
     content->contentDisposition()->setFilename( filename );
   }
 
   // Consume what's left
-  while ( pos<structure.size() && structure[pos]!=')' ) {
+  while ( pos < structure.size() && structure[pos] != ')' ) {
     skipLeadingSpaces( structure, pos );
     parseSentence( structure, pos );
     skipLeadingSpaces( structure, pos );
@@ -433,7 +435,7 @@ QByteArray FetchJobPrivate::parseSentence( const QByteArray &structure, int &pos
 
   skipLeadingSpaces( structure, pos );
 
-  if ( structure[pos]!='(' ) {
+  if ( structure[pos] != '(' ) {
     return parseString( structure, pos );
   }
 
@@ -458,12 +460,12 @@ QByteArray FetchJobPrivate::parseSentence( const QByteArray &structure, int &pos
       stack--;
       break;
     default:
-      skipLeadingSpaces(structure, pos);
-      parseString(structure, pos);
-      skipLeadingSpaces(structure, pos);
+      skipLeadingSpaces( structure, pos );
+      parseString( structure, pos );
+      skipLeadingSpaces( structure, pos );
       break;
     }
-  } while ( pos<structure.size() && stack!=0 );
+  } while ( pos < structure.size() && stack != 0 );
 
   result = structure.mid( start, pos - start );
 
@@ -484,12 +486,12 @@ QByteArray FetchJobPrivate::parseString( const QByteArray &structure, int &pos )
     pos++;
     Q_FOREVER {
       if ( structure[pos] == '\\' ) {
-        pos+= 2;
+        pos += 2;
         foundSlash = true;
         continue;
       }
       if ( structure[pos] == '"' ) {
-        result = structure.mid( start+1, pos - start - 1);
+        result = structure.mid( start + 1, pos - start - 1 );
         pos++;
         break;
       }
@@ -497,27 +499,38 @@ QByteArray FetchJobPrivate::parseString( const QByteArray &structure, int &pos )
     }
   } else { // unquoted string
     Q_FOREVER {
-      if ( structure[pos] == ' ' || structure[pos] == '(' || structure[pos] == ')' || structure[pos] == '[' || structure[pos] == ']' || structure[pos] == '\n' || structure[pos] == '\r' || structure[pos] == '"') {
+      if ( structure[pos] == ' ' ||
+           structure[pos] == '(' ||
+           structure[pos] == ')' ||
+           structure[pos] == '[' ||
+           structure[pos] == ']' ||
+           structure[pos] == '\n' ||
+           structure[pos] == '\r' ||
+           structure[pos] == '"' ) {
         break;
       }
-      if (structure[pos] == '\\')
+      if ( structure[pos] == '\\' ) {
         foundSlash = true;
+      }
       pos++;
     }
 
     result = structure.mid( start, pos - start );
 
     // transform unquoted NIL
-    if ( result == "NIL" )
+    if ( result == "NIL" ) {
       result.clear();
+    }
   }
 
   // simplify slashes
   if ( foundSlash ) {
-    while ( result.contains( "\\\"" ) )
+    while ( result.contains( "\\\"" ) ) {
       result.replace( "\\\"", "\"" );
-    while ( result.contains( "\\\\" ) )
+    }
+    while ( result.contains( "\\\\" ) ) {
       result.replace( "\\\\", "\\" );
+    }
   }
 
   return result;
@@ -525,7 +538,9 @@ QByteArray FetchJobPrivate::parseString( const QByteArray &structure, int &pos )
 
 void FetchJobPrivate::skipLeadingSpaces( const QByteArray &structure, int &pos )
 {
-  while ( structure[pos]==' ' && pos<structure.size() ) pos++;
+  while ( structure[pos] == ' ' && pos < structure.size() ) {
+    pos++;
+  }
 }
 
-#include "fetchjob.moc"
+#include "moc_fetchjob.cpp"
