@@ -30,8 +30,8 @@
 
 using namespace KIMAP;
 
-Q_DECLARE_METATYPE(KTcpSocket::Error)
-Q_DECLARE_METATYPE(KSslErrorUiData)
+Q_DECLARE_METATYPE( KTcpSocket::Error )
+Q_DECLARE_METATYPE( KSslErrorUiData )
 static const int _kimap_socketErrorTypeId = qRegisterMetaType<KTcpSocket::Error>();
 static const int _kimap_sslErrorUiData = qRegisterMetaType<KSslErrorUiData>();
 
@@ -43,7 +43,7 @@ SessionThread::SessionThread( const QString &hostName, quint16 port, Session *pa
   // Yeah, sounds weird, but QThread object is linked to the parent
   // thread not to itself, and I'm too lazy to introduce yet another
   // internal QObject
-  moveToThread(this);
+  moveToThread( this );
 }
 
 SessionThread::~SessionThread()
@@ -60,7 +60,7 @@ SessionThread::~SessionThread()
 
 void SessionThread::sendData( const QByteArray &payload )
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
 
   m_dataQueue.enqueue( payload );
   QTimer::singleShot( 0, this, SLOT(writeDataQueue()) );
@@ -68,7 +68,7 @@ void SessionThread::sendData( const QByteArray &payload )
 
 void SessionThread::writeDataQueue()
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
 
   while ( !m_dataQueue.isEmpty() ) {
     m_socket->write( m_dataQueue.dequeue() );
@@ -77,9 +77,9 @@ void SessionThread::writeDataQueue()
 
 void SessionThread::readMessage()
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
 
-  if ( m_stream->availableDataSize()==0 ) {
+  if ( m_stream->availableDataSize() == 0 ) {
     return;
   }
 
@@ -93,10 +93,10 @@ void SessionThread::readMessage()
         if ( string == "NIL" ) {
           *payload << Message::Part( QList<QByteArray>() );
         } else {
-          *payload << Message::Part(string);
+          *payload << Message::Part( string );
         }
       } else if ( m_stream->hasList() ) {
-        *payload << Message::Part(m_stream->readParenthesizedList());
+        *payload << Message::Part( m_stream->readParenthesizedList() );
       } else if ( m_stream->hasResponseCode() ) {
         payload = &message.responseCode;
       } else if ( m_stream->atResponseCodeEnd() ) {
@@ -104,9 +104,9 @@ void SessionThread::readMessage()
       } else if ( m_stream->hasLiteral() ) {
         QByteArray literal;
         while ( !m_stream->atLiteralEnd() ) {
-          literal+= m_stream->readLiteralPart();
+          literal += m_stream->readLiteralPart();
         }
-        *payload << Message::Part(literal);
+        *payload << Message::Part( literal );
       } else {
         // Oops! Something really bad happened, we won't be able to recover
         // so close the socket immediately
@@ -116,13 +116,13 @@ void SessionThread::readMessage()
       }
     }
 
-    emit responseReceived(message);
+    emit responseReceived( message );
 
-  } catch (KIMAP::ImapParserException e) {
+  } catch ( KIMAP::ImapParserException e ) {
     qWarning() << "The stream parser raised an exception:" << e.what();
   }
 
-  if ( m_stream->availableDataSize()>1 ) {
+  if ( m_stream->availableDataSize() > 1 ) {
     QTimer::singleShot( 0, this, SLOT(readMessage()) );
   }
 
@@ -141,14 +141,14 @@ void SessionThread::doCloseSocket()
 
 void SessionThread::reconnect()
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
 
   if ( m_socket->state() != SessionSocket::ConnectedState &&
        m_socket->state() != SessionSocket::ConnectingState ) {
-    if (m_encryptedMode) {
-      m_socket->connectToHostEncrypted(m_hostName, m_port);
+    if ( m_encryptedMode ) {
+      m_socket->connectToHostEncrypted( m_hostName, m_port );
     } else {
-      m_socket->connectToHost(m_hostName, m_port);
+      m_socket->connectToHost( m_hostName, m_port );
     }
   }
 }
@@ -168,7 +168,7 @@ void SessionThread::run()
            this, SLOT(socketError()) );
   connect( m_socket, SIGNAL(bytesWritten(qint64)),
            m_session, SLOT(socketActivity()) );
-  if ( m_socket->metaObject()->indexOfSignal("encryptedBytesWritten(qint64)" ) > -1 ) {
+  if ( m_socket->metaObject()->indexOfSignal( "encryptedBytesWritten(qint64)" ) > -1 ) {
       connect( m_socket, SIGNAL(encryptedBytesWritten(qint64)), // needs kdelibs > 4.8
                m_session, SLOT(socketActivity()) );
   }
@@ -187,7 +187,7 @@ void SessionThread::run()
 
 void SessionThread::startSsl(const KTcpSocket::SslVersion &version)
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
 
   if ( version == KTcpSocket::AnySslVersion ) {
     doSslFallback = true;
@@ -209,7 +209,7 @@ void SessionThread::startSsl(const KTcpSocket::SslVersion &version)
   }
 
   m_socket->ignoreSslErrors();
-  connect(m_socket, SIGNAL(encrypted()), this, SLOT(sslConnected()));
+  connect( m_socket, SIGNAL(encrypted()), this, SLOT(sslConnected()) );
   m_socket->startClientEncryption();
 }
 
@@ -225,8 +225,8 @@ void SessionThread::socketDisconnected()
 void SessionThread::socketError()
 {
   QMutexLocker locker( &m_mutex );
+
   if ( doSslFallback ) {
-    locker.unlock(); // disconnectFromHost() ends up calling reconnect()
     m_socket->disconnectFromHost();
   } else {
     QMetaObject::invokeMethod( m_session, "socketError" );
@@ -235,41 +235,42 @@ void SessionThread::socketError()
 
 void SessionThread::sslConnected()
 {
-  QMutexLocker locker(&m_mutex);
+  QMutexLocker locker( &m_mutex );
   KSslCipher cipher = m_socket->sessionCipher();
 
-  if ( m_socket->sslErrors().count() > 0 || m_socket->encryptionMode() != KTcpSocket::SslClientMode
-      || cipher.isNull() || cipher.usedBits() == 0) {
-      kDebug() << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull()
-                    << ", cipher.usedBits() is" << cipher.usedBits()
-                    << ", the socket says:" <<  m_socket->errorString()
-                    << "and the list of SSL errors contains"
-                    << m_socket->sslErrors().count() << "items.";
-     KSslErrorUiData errorData(m_socket);
-     emit sslError(errorData);
+  if ( m_socket->sslErrors().count() > 0 ||
+       m_socket->encryptionMode() != KTcpSocket::SslClientMode ||
+       cipher.isNull() || cipher.usedBits() == 0 ) {
+     kDebug() << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull()
+              << ", cipher.usedBits() is" << cipher.usedBits()
+              << ", the socket says:" <<  m_socket->errorString()
+              << "and the list of SSL errors contains"
+              << m_socket->sslErrors().count() << "items.";
+     KSslErrorUiData errorData( m_socket );
+     emit sslError( errorData );
   } else {
     doSslFallback = false;
     kDebug() << "TLS negotiation done.";
     m_encryptedMode = true;
-    emit encryptionNegotiationResult(true, m_socket->negotiatedSslVersion());
+    emit encryptionNegotiationResult( true, m_socket->negotiatedSslVersion() );
   }
 }
 
 void SessionThread::sslErrorHandlerResponse(bool response)
 {
-  QMutexLocker locker(&m_mutex);
-  if (response) {
+  QMutexLocker locker( &m_mutex );
+  if ( response ) {
     m_encryptedMode = true;
-    emit encryptionNegotiationResult(true, m_socket->negotiatedSslVersion());
+    emit encryptionNegotiationResult( true, m_socket->negotiatedSslVersion() );
   } else {
      m_encryptedMode = false;
      //reconnect in unencrypted mode, so new commands can be issued
      m_socket->disconnectFromHost();
      m_socket->waitForDisconnected();
-     m_socket->connectToHost(m_hostName, m_port);
-     emit encryptionNegotiationResult(false, KTcpSocket::UnknownSslVersion);
+     m_socket->connectToHost( m_hostName, m_port );
+     emit encryptionNegotiationResult( false, KTcpSocket::UnknownSslVersion );
   }
 }
 
-#include "sessionthread_p.moc"
+#include "moc_sessionthread_p.cpp"
 
