@@ -30,13 +30,13 @@
 #include <kmessagebox.h>
 
 #include <QtCore/QObject>
-#include <QtGui/QCheckBox>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLayout>
-#include <QtGui/QPushButton>
-#include <QtGui/QRadioButton>
-#include <QtGui/QSpinBox>
+#include <QCheckBox>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QSpinBox>
 
 using namespace KLDAP;
 
@@ -403,8 +403,8 @@ void LdapConfigWidget::Private::loadData( LdapSearch *, const LdapObject &object
   LdapAttrMap::ConstIterator end( object.attributes().constEnd() );
   for ( LdapAttrMap::ConstIterator it = object.attributes().constBegin();
         it != end; ++it ) {
-    LdapAttrValue::ConstIterator end2( (*it).constEnd() );
-    for ( LdapAttrValue::ConstIterator it2 = (*it).constBegin();
+    LdapAttrValue::ConstIterator end2( ( *it ).constEnd() );
+    for ( LdapAttrValue::ConstIterator it2 = ( *it ).constBegin();
           it2 != end2; ++it2 ) {
       mQResult.push_back( QString::fromUtf8( *it2 ) );
     }
@@ -888,4 +888,4 @@ void LdapConfigWidget::setFeatures( LdapConfigWidget::WinFlags features )
   d->initWidget();
 }
 
-#include "ldapconfigwidget.moc"
+#include "moc_ldapconfigwidget.cpp"
