@@ -103,7 +103,7 @@ bool Content::hasContent() const
 
 void Content::setContent( const QList<QByteArray> &l )
 {
-  Q_D(Content);
+  Q_D( Content );
   //qDebug("Content::setContent( const QList<QByteArray> &l ) : start");
   d->head.clear();
   d->body.clear();
@@ -132,7 +132,7 @@ void Content::setContent( const QList<QByteArray> &l )
 
 void Content::setContent( const QByteArray &s )
 {
-  Q_D(Content);
+  Q_D( Content );
   KMime::HeaderParsing::extractHeaderAndBody( s, d->head, d->body );
 }
 
@@ -144,8 +144,9 @@ QByteArray Content::head() const
 void Content::setHead( const QByteArray &head )
 {
   d_ptr->head = head;
-  if ( !head.endsWith( '\n' ) )
+  if ( !head.endsWith( '\n' ) ) {
     d_ptr->head += '\n';
+  }
 }
 
 QByteArray Content::body() const
@@ -187,13 +188,13 @@ void Content::parse()
   qDeleteAll( h_eaders );
   h_eaders.clear();
   h_eaders = HeaderParsing::parseHeaders( d->head );
-  foreach( Headers::Base *h, h_eaders ) {
+  foreach ( Headers::Base *h, h_eaders ) {
     h->setParent( this );
   }
 
   // If we are frozen, save the body as-is. This is done because parsing
   // changes the content (it loses preambles and epilogues, converts uuencode->mime, etc.)
-  if( d->frozen ) {
+  if ( d->frozen ) {
     d->frozenBody = d->body;
   }
 
@@ -202,20 +203,20 @@ void Content::parse()
   d->multipartContents.clear();
   d->clearBodyMessage();
   Headers::ContentType *ct = contentType();
-  if( ct->isText() ) {
+  if ( ct->isText() ) {
     // This content is either text, or of unknown type.
 
-    if( d->parseUuencoded() ) {
+    if ( d->parseUuencoded() ) {
       // This is actually uuencoded content generated by broken software.
-    } else if( d->parseYenc() ) {
+    } else if ( d->parseYenc() ) {
       // This is actually yenc content generated by broken software.
     } else {
       // This is just plain text.
     }
-  } else if( ct->isMultipart() ) {
+  } else if ( ct->isMultipart() ) {
     // This content claims to be MIME multipart.
 
-    if( d->parseMultipart() ) {
+    if ( d->parseMultipart() ) {
       // This is actual MIME multipart content.
     } else {
       // Parsing failed; treat this content as "text/plain".
@@ -252,12 +253,12 @@ void Content::setFrozen( bool frozen )
 void Content::assemble()
 {
   Q_D( Content );
-  if( d->frozen ) {
+  if ( d->frozen ) {
     return;
   }
 
   d->head = assembleHeaders();
-  foreach( Content *c, contents() ) {
+  foreach ( Content *c, contents() ) {
     c->assemble();
   }
 }
@@ -265,8 +266,8 @@ void Content::assemble()
 QByteArray Content::assembleHeaders()
 {
   QByteArray newHead;
-  foreach( const Headers::Base *h, h_eaders ) {
-    if( !h->isEmpty() ) {
+  foreach ( const Headers::Base *h, h_eaders ) {
+    if ( !h->isEmpty() ) {
       newHead += h->as7BitString() + '\n';
     }
   }
@@ -276,7 +277,7 @@ QByteArray Content::assembleHeaders()
 
 void Content::clear()
 {
-  Q_D(Content);
+  Q_D( Content );
   qDeleteAll( h_eaders );
   h_eaders.clear();
   clearContents();
@@ -286,8 +287,8 @@ void Content::clear()
 
 void Content::clearContents( bool del )
 {
-  Q_D(Content);
-  if( del ) {
+  Q_D( Content );
+  if ( del ) {
     qDeleteAll( d->multipartContents );
   }
   d->multipartContents.clear();
@@ -296,7 +297,7 @@ void Content::clearContents( bool del )
 
 QByteArray Content::encodedContent( bool useCrLf )
 {
-  Q_D(Content);
+  Q_D( Content );
   QByteArray e;
 
   // Head.
@@ -316,21 +317,21 @@ QByteArray Content::encodedBody()
   Q_D( Content );
   QByteArray e;
   // Body.
-  if( d->frozen ) {
+  if ( d->frozen ) {
     // This Content is frozen.
-    if( d->frozenBody.isEmpty() ) {
+    if ( d->frozenBody.isEmpty() ) {
       // This Content has never been parsed.
       e += d->body;
     } else {
       // Use the body as it was before parsing.
       e += d->frozenBody;
     }
-  } else if( bodyIsMessage() && d->bodyAsMessage ) {
+  } else if ( bodyIsMessage() && d->bodyAsMessage ) {
     // This is an encapsulated message
     // No encoding needed, as the ContentTransferEncoding can only be 7bit
     // for encapsulated messages
     e += d->bodyAsMessage->encodedContent();
-  } else if( !d->body.isEmpty() ) {
+  } else if ( !d->body.isEmpty() ) {
     // This is a single-part Content.
     Headers::ContentTransferEncoding *enc = contentTransferEncoding();
 
@@ -351,19 +352,21 @@ QByteArray Content::encodedBody()
     Headers::ContentType *ct=contentType();
     QByteArray boundary = "\n--" + ct->boundary();
 
-    if ( !d->preamble.isEmpty() )
+    if ( !d->preamble.isEmpty() ) {
       e += d->preamble;
+    }
 
     //add all (encoded) contents separated by boundaries
     foreach ( Content *c, d->multipartContents ) {
-      e+=boundary + '\n';
+      e += boundary + '\n';
       e += c->encodedContent( false );  // don't convert LFs here, we do that later!!!!!
     }
     //finally append the closing boundary
     e += boundary+"--\n";
 
-    if ( !d->epilogue.isEmpty() )
+    if ( !d->epilogue.isEmpty() ) {
       e += d->epilogue;
+    }
   };
   return e;
 }
@@ -382,7 +385,7 @@ QByteArray Content::decodedContent()
     ret = d_ptr->body;
     removeTrailingNewline = true;
   } else {
-    switch( ec->encoding() ) {
+    switch ( ec->encoding() ) {
     case Headers::CEbase64 :
     {
       KMime::Codec *codec = KMime::Codec::codecForName( "base64" );
@@ -412,7 +415,7 @@ QByteArray Content::decodedContent()
     }
   }
 
-  if ( removeTrailingNewline && ( ret.size() > 0 ) && ( ret[ret.size()-1] == '\n') ) {
+  if ( removeTrailingNewline && ( ret.size() > 0 ) && ( ret[ret.size() - 1] == '\n' ) ) {
     ret.resize( ret.size() - 1 );
   }
 
@@ -772,7 +775,7 @@ int Content::size()
 
 int Content::storageSize() const
 {
-  const Q_D(Content);
+  const Q_D( Content );
   int s = d->head.size();
 
   if ( d->contents().isEmpty() ) {
@@ -791,7 +794,7 @@ int Content::storageSize() const
 
 int Content::lineCount() const
 {
-  const Q_D(Content);
+  const Q_D( Content );
   int ret = 0;
   if ( !isTopLevel() ) {
     ret += d->head.count( '\n' );
@@ -817,7 +820,7 @@ QList<QByteArray> Content::rawHeaders( const char *name ) const
 
 bool Content::decodeText()
 {
-  Q_D(Content);
+  Q_D( Content );
   Headers::ContentTransferEncoding *enc = contentTransferEncoding();
 
   if ( !contentType()->isText() ) {
@@ -1077,14 +1080,14 @@ bool ContentPrivate::parseYenc()
 {
   Q_Q( Content );
   Parser::YENCEncoded yenc( body );
-  if( !yenc.parse() ) {
+  if ( !yenc.parse() ) {
     return false; // Parsing failed.
   }
 
   Headers::ContentType *ct = q->contentType();
   ct->clear();
 
-  if( yenc.isPartial() ) {
+  if ( yenc.isPartial() ) {
     // Assume there is exactly one decoded part.  Treat this as "message/partial".
     ct->setMimeType( "message/partial" );
     //ct->setId( uniqueString() ); not needed yet
@@ -1131,11 +1134,11 @@ bool ContentPrivate::parseMultipart()
   Q_Q( Content );
   const Headers::ContentType *ct = q->contentType();
   const QByteArray boundary = ct->boundary();
-  if( boundary.isEmpty() ) {
+  if ( boundary.isEmpty() ) {
     return false; // Parsing failed; invalid multipart content.
   }
   Parser::MultiPart mpp( body, boundary );
-  if( !mpp.parse() ) {
+  if ( !mpp.parse() ) {
     return false; // Parsing failed.
   }
 
@@ -1144,7 +1147,7 @@ bool ContentPrivate::parseMultipart()
 
   // Determine the category of the subparts (used in attachments()).
   Headers::contentCategory cat;
-  if( ct->isSubtype( "alternative" ) ) {
+  if ( ct->isSubtype( "alternative" ) ) {
     cat = Headers::CCalternativePart;
   } else {
     cat = Headers::CCmixedPart; // Default to "mixed".
@@ -1154,7 +1157,7 @@ bool ContentPrivate::parseMultipart()
   Q_ASSERT( multipartContents.isEmpty() );
   body.clear();
   QList<QByteArray> parts = mpp.parts();
-  foreach( const QByteArray &part, mpp.parts() ) {
+  foreach ( const QByteArray &part, mpp.parts() ) {
     Content *c = new Content( q );
     c->setContent( part );
     c->setFrozen( frozen );
