@@ -2,7 +2,7 @@
   Copyright (c) 2009 Thomas McGuire <mcguire@kde.org>
 
   Based on KMail and libkdepim code by:
-  Copyright 2007 Laurent Montel <montel@kde.org>
+  Copyright 2007 - 2012 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,6 +23,9 @@
 
 #include "emailquotehighlighter.h"
 #include "emoticontexteditaction.h"
+#include "inserthtmldialog.h"
+#include "tableactionmenu.h"
+#include "insertimagedialog.h"
 
 #include <kmime/kmime_codecs.h>
 
@@ -41,8 +44,8 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QFileInfo>
 #include <QtCore/QPointer>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QTextLayout>
+#include <QKeyEvent>
+#include <QTextLayout>
 
 #include "textutils.h"
 #include <QPlainTextEdit>
@@ -56,9 +59,13 @@ class TextEditPrivate
     TextEditPrivate( TextEdit *parent )
       : actionAddImage( 0 ),
         actionDeleteLine( 0 ),
+        actionInsertHtml( 0 ),
+        actionTable( 0 ),
         q( parent ),
         imageSupportEnabled( false ),
-        emoticonSupportEnabled( false )
+        emoticonSupportEnabled( false ),
+        insertHtmlSupportEnabled( false ),
+        insertTableSupportEnabled( false )
     {
     }
 
@@ -70,7 +77,7 @@ class TextEditPrivate
      *                  be appended to it
      * @param image the actual image to add
      */
-    void addImageHelper( const QString &imageName, const QImage &image );
+    void addImageHelper(const QString &imageName, const QImage &image, int width = -1, int height = -1);
 
     /**
      * Helper function to get the list of all QTextImageFormats in the document.
@@ -97,6 +104,11 @@ class TextEditPrivate
     void _k_slotDeleteLine();
 
     void _k_slotAddEmoticon(const QString&);
+
+    void _k_slotInsertHtml();
+
+
+
     /// The action that triggers _k_slotAddImage()
     KAction *actionAddImage;
 
@@ -104,6 +116,11 @@ class TextEditPrivate
     KAction *actionDeleteLine;
 
     EmoticonTextEditAction *actionAddEmoticon;
+
+    KAction *actionInsertHtml;
+
+    TableActionMenu *actionTable;
+
     /// The parent class
     TextEdit *q;
 
@@ -111,6 +128,10 @@ class TextEditPrivate
     bool imageSupportEnabled;
 
     bool emoticonSupportEnabled;
+
+    bool insertHtmlSupportEnabled;
+
+    bool insertTableSupportEnabled;
     /**
      * The names of embedded images.
      * Used to easily obtain the names of the images.
@@ -227,8 +248,8 @@ void TextEdit::keyPressEvent ( QKeyEvent * e )
       bool isQuotedLine = false;
       int bot = 0; // bot = begin of text after quote indicators
       while ( bot < lineText.length() ) {
-        if( ( lineText[bot] == QChar::fromAscii( '>' ) ) ||
-            ( lineText[bot] == QChar::fromAscii( '|' ) ) ) {
+        if ( ( lineText[bot] == QChar::fromAscii( '>' ) ) ||
+             ( lineText[bot] == QChar::fromAscii( '|' ) ) ) {
           isQuotedLine = true;
           ++bot;
         } else if ( lineText[bot].isSpace() ) {
@@ -345,10 +366,16 @@ void TextEdit::setHighlighterColors( EMailQuoteHighlighter *highlighter )
   Q_UNUSED( highlighter );
 }
 
+
 QString TextEdit::toWrappedPlainText() const
+{
+    QTextDocument *doc = document();
+    return toWrappedPlainText(doc);
+}
+
+QString TextEdit::toWrappedPlainText(QTextDocument* doc) const
 {
   QString temp;
-  QTextDocument *doc = document();
   QTextBlock block = doc->begin();
   while ( block.isValid() ) {
     QTextLayout *layout = block.layout();
@@ -369,13 +396,18 @@ QString TextEdit::toWrappedPlainText() const
   return temp;
 }
 
-QString TextEdit::toCleanPlainText() const
+QString TextEdit::toCleanPlainText(const QString& plainText) const
 {
-  QString temp = toPlainText();
+  QString temp = plainText;
   d->fixupTextEditString( temp );
   return temp;
 }
 
+QString TextEdit::toCleanPlainText() const
+{
+  return toCleanPlainText(toPlainText());
+}
+
 void TextEdit::createActions( KActionCollection *actionCollection )
 {
   KRichTextWidget::createActions( actionCollection );
@@ -392,13 +424,38 @@ void TextEdit::createActions( KActionCollection *actionCollection )
     connect( d->actionAddEmoticon, SIGNAL(emoticonActivated(QString)), SLOT(_k_slotAddEmoticon(QString)) );
   }
 
+  if ( d->insertHtmlSupportEnabled ) {
+    d->actionInsertHtml = new KAction( i18n( "Insert HTML" ), this );
+    actionCollection->addAction( QLatin1String( "insert_html" ), d->actionInsertHtml );
+    connect( d->actionInsertHtml, SIGNAL(triggered(bool)), SLOT(_k_slotInsertHtml()) );
+  }
+
+  if ( d->insertTableSupportEnabled ) {
+    d->actionTable = new TableActionMenu( actionCollection, this );
+    d->actionTable->setIcon( KIcon( QLatin1String( "table" ) ) );
+    d->actionTable->setText( i18n( "Table" ) );
+    d->actionTable->setDelayed( false );
+    actionCollection->addAction( QLatin1String( "insert_table" ), d->actionTable );
+  }
+
+
   d->actionDeleteLine = new KAction( i18n( "Delete Line" ), this );
   d->actionDeleteLine->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_K ) );
   actionCollection->addAction( QLatin1String( "delete_line" ), d->actionDeleteLine );
   connect( d->actionDeleteLine, SIGNAL(triggered(bool)), SLOT(_k_slotDeleteLine()) );
 }
 
-void TextEdit::addImage( const KUrl &url )
+void TextEdit::addImage(const KUrl &url, int width, int height)
+{
+  addImageHelper( url, width, height );
+}
+
+void TextEdit::addImage( const KUrl &url)
+{
+  addImageHelper( url );
+}
+
+void TextEdit::addImageHelper(const KUrl &url, int width, int height)
 {
   QImage image;
   if ( !image.load( url.path() ) ) {
@@ -411,7 +468,7 @@ void TextEdit::addImage( const KUrl &url )
   QFileInfo fi( url.path() );
   QString imageName = fi.baseName().isEmpty() ? QLatin1String( "image.png" )
                                               : QString( fi.baseName() + QLatin1String( ".png" ) );
-  d->addImageHelper( imageName, image );
+  d->addImageHelper( imageName, image, width, height );
 }
 
 void TextEdit::loadImage ( const QImage &image, const QString &matchName,
@@ -427,7 +484,7 @@ void TextEdit::loadImage ( const QImage &image, const QString &matchName,
         QTextImageFormat imageFormat = fragment.charFormat().toImageFormat();
         if ( imageFormat.isValid() && imageFormat.name() == matchName ) {
           int pos = fragment.position();
-          if ( !cursorPositionsToSkip.contains( pos )  ) {
+          if ( !cursorPositionsToSkip.contains( pos ) ) {
             QTextCursor cursor( document() );
             cursor.setPosition( pos );
             cursor.setPosition( pos + 1, QTextCursor::KeepAnchor );
@@ -456,7 +513,7 @@ void TextEdit::loadImage ( const QImage &image, const QString &matchName,
   }
 }
 
-void TextEditPrivate::addImageHelper( const QString &imageName, const QImage &image )
+void TextEditPrivate::addImageHelper( const QString &imageName, const QImage &image,int width, int height )
 {
   QString imageNameToAdd = imageName;
   QTextDocument *document = q->document();
@@ -482,7 +539,15 @@ void TextEditPrivate::addImageHelper( const QString &imageName, const QImage &im
     document->addResource( QTextDocument::ImageResource, QUrl( imageNameToAdd ), image );
     mImageNames << imageNameToAdd;
   }
-  q->textCursor().insertImage( imageNameToAdd );
+  if ( width != -1 && height != -1 ) {
+      QTextImageFormat format;
+      format.setName( imageNameToAdd );
+      format.setWidth( width );
+      format.setHeight( height );
+      q->textCursor().insertImage( format );
+  } else {
+      q->textCursor().insertImage( imageNameToAdd );
+  }
   q->enableRichTextMode();
 }
 
@@ -540,8 +605,8 @@ QList<QTextImageFormat> TextEditPrivate::embeddedImageFormats() const
         QTextImageFormat imageFormat = fragment.charFormat().toImageFormat();
         if ( imageFormat.isValid() ) {
           //TODO: Replace with a way to see if an image is an embedded image or a remote
-          QUrl url(imageFormat.name());
-          if( !url.isValid() || !url.scheme().startsWith( QLatin1String( "http" ) ) ) {
+          QUrl url( imageFormat.name() );
+          if ( !url.isValid() || !url.scheme().startsWith( QLatin1String( "http" ) ) ) {
             retList.append( imageFormat );
           }
         }
@@ -558,21 +623,35 @@ void TextEditPrivate::_k_slotAddEmoticon( const QString& text)
   cursor.insertText( text );
 }
 
+void TextEditPrivate::_k_slotInsertHtml()
+{
+  if ( q->textMode() == KRichTextEdit::Rich ) {
+    InsertHtmlDialog *dialog = new InsertHtmlDialog( q );
+    if ( dialog->exec() ) {
+      const QString str = dialog->html();
+      if ( !str.isEmpty() ) {
+        QTextCursor cursor = q->textCursor();
+        cursor.insertHtml( str );
+      }
+    }
+    delete dialog;
+  }
+}
+
 void TextEditPrivate::_k_slotAddImage()
 {
-  QStringList mimetypes = KImageIO::mimeTypes( KImageIO::Reading );
-  QPointer<KFileDialog> fdlg = new KFileDialog( QString(), mimetypes.join(QLatin1String(" ")), q );
-  fdlg->setOperationMode( KFileDialog::Other );
-  fdlg->setCaption( i18n( "Add Image" ) );
-  fdlg->okButton()->setGuiItem( KGuiItem( i18n( "&Add" ), QLatin1String( "document-open" ) ) );
-  fdlg->setMode( KFile::Files );
-  if ( fdlg->exec() == KDialog::Accepted && fdlg ) {
-    const KUrl::List files = fdlg->selectedUrls();
-    foreach ( const KUrl &url, files ) {
-      q->addImage( url );
+  QPointer<InsertImageDialog> dlg = new InsertImageDialog( q );
+  if ( dlg->exec() == KDialog::Accepted && dlg ) {
+    const KUrl url = dlg->imageUrl();
+    int imageWidth = -1;
+    int imageHeight = -1;
+    if ( !dlg->keepOriginalSize() ) {
+        imageWidth = dlg->imageWidth();
+        imageHeight = dlg->imageHeight();
     }
+    q->addImage( url, imageWidth, imageHeight );
   }
-  delete fdlg;
+  delete dlg;
 }
 
 void KPIMTextEdit::TextEdit::enableImageActions()
@@ -595,6 +674,26 @@ bool KPIMTextEdit::TextEdit::isEnableEmoticonActions() const
   return d->emoticonSupportEnabled;
 }
 
+void KPIMTextEdit::TextEdit::enableInsertHtmlActions()
+{
+  d->insertHtmlSupportEnabled = true;
+}
+
+bool KPIMTextEdit::TextEdit::isEnableInsertHtmlActions() const
+{
+  return d->insertHtmlSupportEnabled;
+}
+
+bool KPIMTextEdit::TextEdit::isEnableInsertTableActions() const
+{
+  return d->insertTableSupportEnabled;
+}
+
+void KPIMTextEdit::TextEdit::enableInsertTableActions()
+{
+  d->insertTableSupportEnabled = true;
+}
+
 
 QByteArray KPIMTextEdit::TextEdit::imageNamesToContentIds(
   const QByteArray &htmlBody, const KPIMTextEdit::ImageList &imageList )
@@ -715,7 +814,7 @@ void TextEdit::deleteCurrentLine()
       return;
     }
   }
-
 }
 
-#include "textedit.moc"
+
+#include "moc_textedit.cpp"
