@@ -33,7 +33,7 @@
 #include <QtCore/QCoreApplication>
 #include <QtCore/QFile>
 #include <QtCore/QRegExp>
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
 #include <climits>
 
@@ -143,7 +143,7 @@ QString LinkLocator::getUrl()
       mPos++;
     }
 
-    if ( isEmptyUrl(url) || ( url.length() > maxUrlLen() ) ) {
+    if ( isEmptyUrl( url ) || ( url.length() > maxUrlLen() ) ) {
       mPos = start;
       url = "";
     } else {
@@ -185,37 +185,37 @@ bool LinkLocator::atUrl() const
 
   QChar ch = mText[mPos];
   return
-    ( ch == 'h' && ( mText.mid( mPos, 7 ) == QLatin1String("http://") ||
-                     mText.mid( mPos, 8 ) == QLatin1String("https://") ) ) ||
-    ( ch == 'v' && mText.mid( mPos, 6 ) == QLatin1String("vnc://") ) ||
-    ( ch == 'f' && ( mText.mid( mPos, 7 ) == QLatin1String("fish://") ||
-                     mText.mid( mPos, 6 ) == QLatin1String("ftp://") ||
-                     mText.mid( mPos, 7 ) == QLatin1String("ftps://") ) ) ||
-    ( ch == 's' && ( mText.mid( mPos, 7 ) == QLatin1String("sftp://") ||
-                     mText.mid( mPos, 6 ) == QLatin1String("smb://") ) ) ||
-    ( ch == 'm' && mText.mid( mPos, 7 ) == QLatin1String("mailto:") ) ||
-    ( ch == 'w' && mText.mid( mPos, 4 ) == QLatin1String("www.") ) ||
-    ( ch == 'f' && ( mText.mid( mPos, 4 ) == QLatin1String("ftp.") ||
-                     mText.mid( mPos, 7 ) == QLatin1String("file://" ) ) )||
-    ( ch == 'n' && mText.mid( mPos, 5 ) == QLatin1String("news:") );
+    ( ch == 'h' && ( mText.mid( mPos, 7 ) == QLatin1String( "http://" ) ||
+                     mText.mid( mPos, 8 ) == QLatin1String( "https://" ) ) ) ||
+    ( ch == 'v' && mText.mid( mPos, 6 ) == QLatin1String( "vnc://" ) ) ||
+    ( ch == 'f' && ( mText.mid( mPos, 7 ) == QLatin1String( "fish://" ) ||
+                     mText.mid( mPos, 6 ) == QLatin1String( "ftp://" ) ||
+                     mText.mid( mPos, 7 ) == QLatin1String( "ftps://" ) ) ) ||
+    ( ch == 's' && ( mText.mid( mPos, 7 ) == QLatin1String( "sftp://" ) ||
+                     mText.mid( mPos, 6 ) == QLatin1String( "smb://" ) ) ) ||
+    ( ch == 'm' && mText.mid( mPos, 7 ) == QLatin1String( "mailto:" ) ) ||
+    ( ch == 'w' && mText.mid( mPos, 4 ) == QLatin1String( "www." ) ) ||
+    ( ch == 'f' && ( mText.mid( mPos, 4 ) == QLatin1String( "ftp." ) ||
+                     mText.mid( mPos, 7 ) == QLatin1String( "file://" ) ) )||
+    ( ch == 'n' && mText.mid( mPos, 5 ) == QLatin1String( "news:" ) );
 }
 
 bool LinkLocator::isEmptyUrl( const QString &url ) const
 {
   return url.isEmpty() ||
-    url == QLatin1String("http://") ||
-    url == QLatin1String("https://") ||
-    url == QLatin1String("fish://") ||
-    url == QLatin1String("ftp://") ||
-    url == QLatin1String("ftps://") ||
-    url == QLatin1String("sftp://") ||
-    url == QLatin1String("smb://") ||
-    url == QLatin1String("vnc://") ||
-    url == QLatin1String("mailto") ||
-    url == QLatin1String("www") ||
-    url == QLatin1String("ftp") ||
-    url == QLatin1String("news") ||
-    url == QLatin1String("news://");
+    url == QLatin1String( "http://" ) ||
+    url == QLatin1String( "https://" ) ||
+    url == QLatin1String( "fish://" ) ||
+    url == QLatin1String( "ftp://" ) ||
+    url == QLatin1String( "ftps://" ) ||
+    url == QLatin1String( "sftp://" ) ||
+    url == QLatin1String( "smb://" ) ||
+    url == QLatin1String( "vnc://" ) ||
+    url == QLatin1String( "mailto" ) ||
+    url == QLatin1String( "www" ) ||
+    url == QLatin1String( "ftp" ) ||
+    url == QLatin1String( "news" ) ||
+    url == QLatin1String( "news://" );
 }
 
 QString LinkLocator::getEmailAddress()
@@ -336,12 +336,10 @@ QString LinkLocator::convertToHtml( const QString &plainText, int flags,
         }
         continue;
       } else if ( ch == '\t' ) {
-        do
-        {
+        do {
           result += "&nbsp;";
           x++;
-        }
-        while ( ( x & 7 ) != 0 );
+        } while ( ( x & 7 ) != 0 );
         x--;
         startOfLine = false;
         continue;
@@ -453,13 +451,13 @@ QString LinkLocator::highlightedText()
   }
 
   const QChar ch = mText[mPos];
-  if ( ch != '/' && ch != '*' && ch != '_' ) {
+  if ( ch != '/' && ch != '*' && ch != '_' && ch != '-' ) {
     return QString();
   }
 
   QRegExp re =
     QRegExp( QString( "\\%1((\\w+)([\\s-']\\w+)*( ?[,.:\\?!;])?)\\%2" ).arg( ch ).arg( ch ) );
-  re.setMinimal(true);
+  re.setMinimal( true );
   if ( re.indexIn( mText, mPos ) == mPos ) {
     int length = re.matchedLength();
     // there must be a whitespace after the closing formating symbol
@@ -474,6 +472,8 @@ QString LinkLocator::highlightedText()
       return "<u>" + re.cap( 1 ) + "</u>";
     case '/':
       return "<i>" + re.cap( 1 ) + "</i>";
+    case '-':
+      return "<strike>" + re.cap( 1 ) + "</strike>";
     }
   }
   return QString();
