@@ -1,22 +1,22 @@
 /*
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
-    Copyright (C) 2007 KovoKs <info@kovoks.nl>
-    Copyright (c) 2008 Thomas McGuire <thomas.mcguire@gmx.net>
+  Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+  Copyright (C) 2007 KovoKs <info@kovoks.nl>
+  Copyright (c) 2008 Thomas McGuire <thomas.mcguire@gmx.net>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+  This library is free software; you can redistribute it and/or modify it
+  under the terms of the GNU Library General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or (at your
+  option) any later version.
 
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+  This library is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+  License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 // Own
@@ -37,8 +37,7 @@
 
 using namespace MailTransport;
 
-namespace MailTransport
-{
+namespace MailTransport {
 
 class ServerTestPrivate
 {
@@ -128,8 +127,8 @@ QList< int > ServerTestPrivate::parseAuthenticationList( const QStringList &auth
 {
   QList< int > result;
   for ( QStringList::ConstIterator it = authentications.begin();
-        it != authentications.end(); ++it )  {
-    QString current = (*it).toUpper();
+        it != authentications.end(); ++it ) {
+    QString current = ( *it ).toUpper();
     if ( current == QLatin1String( "LOGIN" ) ) {
       result << Transport::EnumAuthenticationType::LOGIN;
     } else if ( current == QLatin1String( "PLAIN" ) ) {
@@ -199,9 +198,8 @@ void ServerTestPrivate::sendInitialCapabilityQuery( MailTransport::Socket *socke
 {
   if ( testProtocol == IMAP_PROTOCOL ) {
     socket->write( QLatin1String( "1 CAPABILITY" ) );
-  }
 
-  else if ( testProtocol == SMTP_PROTOCOL ) {
+  } else if ( testProtocol == SMTP_PROTOCOL ) {
 
       // Detect the hostname which we send with the EHLO command.
       // If there is a fake one set, use that, otherwise use the
@@ -620,4 +618,4 @@ QList< ServerTest::Capability > ServerTest::capabilities() const
   return d->capabilityResults.toList();
 }
 
-#include "servertest.moc"
+#include "moc_servertest.cpp"
